@@ -5,7 +5,12 @@ from qtgql.tools import slot, qproperty
 from typing import Optional, Union
 from PySide6.QtCore import Signal, QObject
 from PySide6.QtQml import QmlElement
-from qtgql.codegen.py.runtime.queryhandler import BaseQueryHandler, QmlOperationConsumerABC, SelectionConfig, OperationMetaData, BaseMutationHandler
+from qtgql.codegen.py.runtime.queryhandler import (BaseQueryHandler,
+                                                   QmlOperationConsumerABC,
+                                                   SelectionConfig,
+                                                   OperationMetaData,
+                                                   BaseMutationHandler,
+                                                   BaseSubscriptionHandler)
 from qtgql.gqltransport.client import  GqlClientMessage, QueryPayload
 from qtgql.codegen.py.runtime.bases import QGraphQListModel
 from .objecttypes import * # noqa
@@ -115,3 +120,18 @@ class Consume{{mutation.name}}(QmlOperationConsumerABC[{{mutation.field.annotati
 
 {% endfor %}
 
+
+
+
+{% for subscription in context.subscriptions %}
+class {{subscription.name}}(BaseSubscriptionHandler[{{subscription.field.annotation}}]):
+
+    {{operation_classvars(subscription)}}
+    {{operation_common(subscription)}}
+
+@QmlElement
+class Consume{{subscription.name}}(QmlOperationConsumerABC):
+    {{operation_consumer_common(subscription)}}
+    def _get_handler(self) -> BaseQueryHandler[{{subscription.field.annotation}}]:
+        return {{subscription.name}}(self)
+{% endfor %}
\ No newline at end of file
