@@ -1,8 +1,7 @@
 from mypy.plugin import Plugin
 from mypy.plugins.attrs import attr_define_makers
 
-attr_define_makers.add("qtgql.itemsystem._core.define_roles")
-attr_define_makers.add("qtgql.autoproperty.define_properties")
+attr_define_makers.add("qtgql.tools.autoproperty.define_properties")
 
 
 class MyPlugin(Plugin):
